@@ -11,4 +11,6 @@ class meets_snap_categorical_eligibility(Variable):
 
     def formula(spm_unit, period, parameters):
         programs = parameters(period).usda.snap.categorical_eligibility
-        return np.any([spm_unit(program, period) for program in programs])
+        return np.any(
+            [spm_unit(program, period) for program in programs], axis=0
+        )
